@@ -19,7 +19,8 @@ def send_json_response(status_code: int, message: dict = None) -> None:
     g.response.status_code = status_code
 
     if message:
-        g.response.headers.add('Content-Type', 'application/json')
+        g.response.content_type = 'application/json; charset=utf-8'
+        g.response.mimetype = 'application/json'
 
         message_str = json.dumps(message)
         g.response.set_data(message_str)
